/*
** Name:        wxsqlite3_version.h
** Purpose:     wxSQLite3 version numbers
** Author:      Ulrich Telle
** Created:     2017-02-01
** Copyright:   (c) 2017-2026 Ulrich Telle
** License:     LGPL-3.0+ WITH WxWindows-exception-3.1
*/

/// \file wxsqlite3_version.h Version information for the wxSQLite3 library

#ifndef WXSQLITE3_VERSION_H_
#define WXSQLITE3_VERSION_H_

#define WXSQLITE3_MAJOR_VERSION      4
#define WXSQLITE3_MINOR_VERSION      12
#define WXSQLITE3_RELEASE_NUMBER     7
#define WXSQLITE3_SUBRELEASE_NUMBER  0
#define WXSQLITE3_VERSION_STRING     "wxSQLite3 4.12.7"

#endif // WXSQLITE3_VERSION_H_
